/*
 * Hedgewars, a free turn based strategy game
 * Copyright (c) 2013 Vittorio Giovara <vittorio.giovara@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */


// TODO: keep on documenting all the weapons
//skip---------------------------------|
//structure------------------------------------------------------------------|


#define AMMOLINE_DEFAULT_QT     "93919294221991210322351110012000000002111001010111110001"
#define AMMOLINE_DEFAULT_PROB   "04050405416006555465544647765766666661555101011154111111"
#define AMMOLINE_DEFAULT_DELAY  "00000000000002055000000400070040000000002200000006000200"
#define AMMOLINE_DEFAULT_CRATE  "13111103121111111231141111111111111112111111011111111111"

#define AMMOLINE_CRAZY_QT       "99999999999999999929999999999999992999999999099999929991"
#define AMMOLINE_CRAZY_PROB     "11111101111111111111111111111111111111111111011111111111"
#define AMMOLINE_CRAZY_DELAY    "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_CRAZY_CRATE    "13111103121111111231141111111111111112111101011111111111"

#define AMMOLINE_PROMODE_QT     "90900090000000000000090000000000000000000000000000000000"
#define AMMOLINE_PROMODE_PROB   "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_PROMODE_DELAY  "00000000000002055000000400070040000000002000000000000200"
#define AMMOLINE_PROMODE_CRATE  "11111101111111111111111111111111111111111001011111111111"

#define AMMOLINE_SHOPPA_QT      "00000099000000000000000000000000000000000000000000000000"
#define AMMOLINE_SHOPPA_PROB    "44444100442444022101121212224220000000020004000100110010"
#define AMMOLINE_SHOPPA_DELAY   "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_SHOPPA_CRATE   "11111101111111111111111111111111111111111011011111111110"

#define AMMOLINE_CLEAN_QT       "10100090000100000110000000000000000000000000000010000000"
#define AMMOLINE_CLEAN_PROB     "04050405416006555465544647765766666661555101011154111211"
#define AMMOLINE_CLEAN_DELAY    "00000000000000000000000000000000000000000000000000000200"
#define AMMOLINE_CLEAN_CRATE    "13111103121111111231141111111111111112111111011111111111"

#define AMMOLINE_MINES_QT       "00000099000900000003000000000000000000000000000000000000"
#define AMMOLINE_MINES_PROB     "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_MINES_DELAY    "00000000000002055000000400070040000000002000000006000200"
#define AMMOLINE_MINES_CRATE    "11111101111111111111111111111111111111111111011111111111"

#define AMMOLINE_PORTALS_QT     "90000090020000000021000000000000001100000900000000000000"
#define AMMOLINE_PORTALS_PROB   "04050405416006555465544647765766666661555101011154111211"
#define AMMOLINE_PORTALS_DELAY  "00000000000002055000000400070040000000002000000006000200"
#define AMMOLINE_PORTALS_CRATE  "13111103121111111231141111111111111112111111011111111111"

#define AMMOLINE_ONEEVERY_QT    "11111191111111111111111111111111111111111111111111111111"
#define AMMOLINE_ONEEVERY_PROB  "11111101111111111111111111111111111111111111111111111111"
#define AMMOLINE_ONEEVERY_DELAY "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_ONEEVERY_CRATE "11111101111111111111111111111111111111111111111111111111"

#define AMMOLINE_HIGHLANDER_QT    "11111191111111111111019111111111100101111101111011001101"
#define AMMOLINE_HIGHLANDER_PROB  "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_HIGHLANDER_DELAY "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_HIGHLANDER_CRATE "00000000000000000000000000000000000000000000000000000000"

#define AMMOLINE_CONSTRUCTION_QT    "11000190000000100100000000000000000000000000000000000000"
#define AMMOLINE_CONSTRUCTION_PROB  "11111101111111111111111111111111111111111111111111111111"
#define AMMOLINE_CONSTRUCTION_DELAY "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_CONSTRUCTION_CRATE "11111101111111111111111111111111111111111111111111111111"

#define AMMOLINE_SHOPPAPRO_QT      "00000099000000000000000000000000000000000000000000000000"
#define AMMOLINE_SHOPPAPRO_PROB    "44444000440444000000000000004000000000000000000000000000"
#define AMMOLINE_SHOPPAPRO_DELAY   "00000000000000000000000000000000000000000000000000000000"
#define AMMOLINE_SHOPPAPRO_CRATE   "11111101111111111111111111111111111111111011011111111211"


//When adding new weapons also insert one element in cDefaultAmmos list (hwconsts.cpp.in)


